Candle class

Immutable OHLCV candle. Fields use double to match the native ABI exactly (NativeCandle in chart_engine_ffi.h).

Constructors

Candle({required double timestamp, required double open, required double high, required double low, required double close, required double volume})
const

Properties

close → double
final
hashCode → int
The hash code for this object.
no setterinherited
high → double
final
low → double
final
open → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → double
final
volume → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited