ChartStyle class

Immutable visual configuration for a NativeChartView.

Maps to the C-side ChartStyle struct. ChartController.setStyle pushes it through FFI; the native overlay polls style_revision so axis/legend/tooltip stay in sync without streaming style over a channel.

Constructors

ChartStyle({Color bgColor = const Color(0xFF0B0E14), Color gridColor = const Color(0x66363B47), Color axisTextColor = const Color(0xFF8D93A2), Color upColor = const Color(0xFF7CFFB2), Color downColor = const Color(0xFFFF6180), Color lineColor = const Color(0xFF7CFFB2), Color areaTopColor = const Color(0xD97CFFB2), Color areaBottomColor = const Color(0x0D7CFFB2), Color crosshairColor = const Color(0xBFFFD466), Color tooltipBgColor = const Color(0xF210161F), Color tooltipTextColor = const Color(0xFFFFFFFF), Color legendTextColor = const Color(0xFF8D93A2), double candleBodyWidthFraction = 0.8, double lineWidthPx = 2.0, double wickWidthPx = 1.0, double crosshairWidthPx = 1.0, double xPadFraction = 0.1, double yPadFraction = 0.1, bool showGrid = true, bool showXAxis = true, bool showYAxis = true, bool showCrosshair = true, bool showTooltip = true, bool showLegend = true, int approxXTicks = 5, int approxYTicks = 5, int yDecimals = 2, bool xIsTimestampMs = true, bool allowPanX = true, bool allowPanY = false, bool allowZoomX = true, bool allowZoomY = false, bool doubleTapToReset = true, String seriesLabel = 'CANDLE', bool showCurrentPriceLine = true, Color currentPriceLineColor = const Color(0xBF7CFFB2)})
const

Properties

allowPanX bool
final
allowPanY bool
final
allowZoomX bool
final
allowZoomY bool
final
approxXTicks int
final
approxYTicks int
final
areaBottomColor Color
final
areaTopColor Color
final
axisTextColor Color
final
bgColor Color
final
candleBodyWidthFraction double
final
crosshairColor Color
final
crosshairWidthPx double
final
currentPriceLineColor Color
final
doubleTapToReset bool
final
downColor Color
final
gridColor Color
final
hashCode int
The hash code for this object.
no setterinherited
legendTextColor Color
final
lineColor Color
final
lineWidthPx double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesLabel String
final
showCrosshair bool
final
showCurrentPriceLine bool
final
showGrid bool
final
showLegend bool
final
showTooltip bool
final
showXAxis bool
final
showYAxis bool
final
tooltipBgColor Color
final
tooltipTextColor Color
final
upColor Color
final
wickWidthPx double
final
xIsTimestampMs bool
final
xPadFraction double
final
yDecimals int
final
yPadFraction double
final

Methods

copyWith({Color? bgColor, Color? gridColor, Color? axisTextColor, Color? upColor, Color? downColor, Color? lineColor, Color? areaTopColor, Color? areaBottomColor, Color? crosshairColor, Color? tooltipBgColor, Color? tooltipTextColor, Color? legendTextColor, double? candleBodyWidthFraction, double? lineWidthPx, double? wickWidthPx, double? crosshairWidthPx, double? xPadFraction, double? yPadFraction, bool? showGrid, bool? showXAxis, bool? showYAxis, bool? showCrosshair, bool? showTooltip, bool? showLegend, int? approxXTicks, int? approxYTicks, int? yDecimals, bool? xIsTimestampMs, bool? allowPanX, bool? allowPanY, bool? allowZoomX, bool? allowZoomY, bool? doubleTapToReset, String? seriesLabel, bool? showCurrentPriceLine, Color? currentPriceLineColor}) ChartStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited